Description Usage Arguments Details Value Note See Also
It ‘defines’ a few extra “data types” to handle all types returned by DoordaHost, like timestamps with time zones.
1 | .json.tabular.to.data.frame(data, column.types, timezone)
|
data |
a |
column.types |
A |
timezone |
The timezone to use for date types. |
If the items in data are named lists the column names will
be inferred from those names. Otherwise they will be
paste0('X', seq_along(data[[1]]))
A data.frame of length(data) rows and
length(data[[1]]) columns.
For NA values, data should have a NULL
item in the correct spot. Ragged arrays are not supported (i.e. all sublists
have to have the same length). These NULL value(s) will be replaced
by NA in-place for the input data.
The corresponding unit tests for a full list of capabilities and data types supported
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.